import { describe, it, expect, vi, beforeEach } from 'vitest';
import { LogLevel, Workspace } from '../../types/serverConfig';
import { compile } from '../bundler/lexBundler.js';
import { Client } from './client';
vi.mock('../bundler/lexBundler.js');
describe('Client', () => {
    let client;
    let mockConnection;
    let mockCtx;
    let mockConfig;
    const mockClientId = 'client-id';
    const mockUrl = 'http://localhost';
    const mockModuleGraph = {
        getFileByModulePath: vi.fn(),
        registerActivePaths: vi.fn(),
        getModuleBoundary: vi.fn(),
        getStaleModules: vi.fn().mockReturnValue(['stale-module']),
    };
    const mockLogger = {
        log: vi.fn(),
    };
    beforeEach(() => {
        mockConnection = {
            send: vi.fn(),
            receive: vi.fn(),
            onClose: vi.fn(),
            close: vi.fn(),
        };
        mockConfig = {
            logLevel: LogLevel.debug,
            paths: [],
            port: 50182,
            rootDir: '',
            workspace: Workspace.Internal,
        };
        mockCtx = {
            config: mockConfig,
            logger: mockLogger,
            moduleGraph: mockModuleGraph,
        };
        vi.mocked(compile).mockResolvedValue({ code: 'code', warnings: [] });
        client = new Client(mockClientId, mockUrl, mockConnection, mockCtx);
    });
    it('should initialize correctly', () => {
        expect(client.clientId).toBe(mockClientId);
        expect(client.url).toBe(mockUrl);
        expect(client.connection).toBe(mockConnection);
        expect(client.ctx).toBe(mockCtx);
        expect(mockConnection.receive).toHaveBeenCalled();
    });
    it('should send data when allowed', () => {
        const data = { type: 'update', data: [] };
        client.send(data);
        expect(mockConnection.send).toHaveBeenCalledWith(data);
    });
    it('should not send data when type is not allowed', () => {
        const data = { type: 'not-allowed', data: [] };
        client.send(data);
        expect(mockCtx.logger.log).toHaveBeenCalledWith(LogLevel.debug, `[LWC Dev Server] Blocking unexpected type of data being sent from server to hmr-client 'not-allowed'`);
        expect(mockConnection.send).not.toHaveBeenCalled();
    });
    it('should handle fetch message correctly', async () => {
        const data = { type: 'fetch', data: { modulePath: 'path1' } };
        mockModuleGraph.getFileByModulePath.mockReturnValue('file1');
        client.getCompileOptions = vi.fn().mockReturnValue({});
        await client.messageCallback(data);
        expect(mockCtx.logger.log).toHaveBeenCalledWith(LogLevel.debug, `[LWC Dev Server] Compiling path1`);
        expect(mockConnection.send).toHaveBeenCalled();
    });
    it('should handle register message correctly', async () => {
        const data = {
            type: 'register',
            data: { modules: [{ modulePath: 'path1', compileOptions: {}, hash: '0' }] },
        };
        mockModuleGraph.registerActivePaths.mockReturnValue(['path1']);
        await client.messageCallback(data);
        expect(client.activePaths.get('path1')).toEqual({});
        expect(mockConnection.send).toHaveBeenCalledWith({
            type: 'update',
            data: [{ modulePath: 'stale-module' }],
        });
    });
    it('should close the connection', () => {
        client.close();
        expect(mockConnection.close).toHaveBeenCalled();
    });
});
//# sourceMappingURL=client.spec.js.map